<?php
/**
 * Enter description here ...
 *
 * @package Logic
 *
 * @author  alessandrobartels
 *
 */
class MediaEventosIntervalo{

    private $_nrOrg;
    private $_nrOrgPadrao;
    private $_mes_ocorrencia;
    private $_dtPagamento;
    private $_evento;
    private $_calculo_folha;
    private $_itens_calculo_fonte;
    private $_listaNrCalculoFolha;


    /**
     * Construtor.
     *
     * @param integer    $nrOrg         Numero da Organizacao de Trabalho.
     * @param integer    $nrOrgPadrao   Numero da Organizacao Padrao.
     * @param TkDateTime $mesOcorrencia Mes de ocorrencia.
     * @param string     $dtPagamento   Data de pagamento.
     *
     * @author alessandrobartels
     */
    public function __construct( $nrOrg, $nrOrgPadrao, TkDateTime $mesOcorrencia, $dtPagamento){

        $this->_nrOrg = $nrOrg;
        $this->_nrOrgPadrao = $nrOrgPadrao;
        $this->_mes_ocorrencia = $mesOcorrencia;
        $this->_dtPagamento = $dtPagamento;

        /*
         * Gerada nova instancia de evento pois os eventos de media sao diferentes dos eventos ja carregados
         * no Calculo ou na Preparacao.
         */
        $this->_evento = new FpaeventomEntity(
            null, $this->_nrOrg, $this->_nrOrgPadrao, $this->_mes_ocorrencia, $this->_dtPagamento
        );
        $this->_calculo_folha_fonte = new FpacalculofolhaEntity;
        $this->_itens_calculo_fonte = new FpaitecalcfolhaEntity;
    }


    // Borba 21/01/2014
    private function _atribuiInicioPeriodoMedia(TkDateTime $dtInicial,TkDateTime $dtFinal,$divisor){
        $dtInicialAux = clone $dtFinal;
        $dtInicialAux->addMonth(-$divisor);
        if ($dtInicial->isLater($dtInicialAux) === true) {
            return $dtInicial;
        } else {
            return $dtInicialAux;
        }
    }

    // Borba 21/01/2014
    private function _sumarizaVal(array $array){
        $getVal=function($row){
            return $row['VAL'];
        };
        $val=array_map($getVal,$array);
        return array_sum($val);
    }

    //BORBA 21/01/2014
    public function calculaMaiorMedia(
        GpevinculomEntity $vinculo, $tipo_movimento, $lista_nr_eventos_origem, TkDateTime $dt_inicial,
        TkDateTime $dt_final, $nrTipoModalidadeCalc, $nrOcorrenciaCalc
    ){
        /** @var $gpevinculom \Folha\Entities\GpeVinculom */
        $fpaparamsindicato = \Folha\Entities\FpaParamsindicato::findOneByNrestruturamAndNrorg($vinculo->historico->getNrestrutsind(),$vinculo->getNrorg());

        if(is_object($fpaparamsindicato)){
            $divisor[1]=$fpaparamsindicato->getNrmesesmedia1();
            $divisor[2]=$fpaparamsindicato->getNrmesesmedia2();
            $divisor[3]=$fpaparamsindicato->getNrmesesmedia3();
        }
        else{
            //@todo MsgCalculo
            MsgCalculo::getInstance()->adicionaMensagem('Não foram encontrados parâmetros de médias para sindicatos.');
            //tk_warning('Não foram encontrados parâmetros de médias para sindicatos.');
        }

        $counter=3;
        $totmediaux=0;
        /*@todo Trazer o calculo do divisor considerando faltas para o escopo da classe*/
        for ($i=1; $i<=$counter; $i++) {
            if($divisor[$i]==0){
                continue;
            }
            $dt_inicial=$this->_atribuiInicioPeriodoMedia($dt_inicial,$dt_final,$divisor[$i]);
            //$divisor[$i]=$this->_calculaDivisorMedias($dt_inicial,$dt_final);
            $media[$i]=$this->calcula( $vinculo, $tipo_movimento, $lista_nr_eventos_origem, $dt_inicial,
                $dt_final, $nrTipoModalidadeCalc, $nrOcorrenciaCalc);

            $totmedia[$i]= $this->_sumarizaVal($media[$i])/$divisor[$i];
            if($totmedia[$i]>$totmediaux){
                $totmediaux=$totmedia[$i];
                $mediaux=$media[$i];
            }           
            // tk_var_dump($media[$i]);
            // tk_warning($this->_sumarizaVal($media[$i]).''.'/'.''.$divisor[$i].'= '.$totmedia[$i]);
        }

        return $mediaux;
    }

    /**
     * Enter description here ...
     *
     * @param GpevinculomEntity     $vinculo              Vinculo.
     * @param integer               $tipo_movimento       Tipo Movimento.
     * @param FpaitecalcfolhaEntity $item_calculo_destino Item Calculo Destino.
     * @param TkDateTime            $dt_inicial           Data Inicial.
     * @param TkDateTime            $dt_final             Data Final.
     * @param integer               $nrTipoModalidadeCalc Numero do Tipo de Modalidade de Calculo.
     * @param integer               $nrOcorrenciaCalc     Numero da Ocorrencia de Calculo.
     * @param integer               $divisor              Divisor.
     *
     * @return void
     *
     * @author alessandrobartels -
     *         alessandrobartels - 27/06/2011 - Implementacao do NRORG no metodo retornaListaEventoMedia().
     *         alessandrobartels - 13/02/2012 - Parametrizado $nrTipoModalidadeCalc, $nrOcorrenciaCalc.
     *         alessandrobartels - 30/11/2012 - Desmembrado a parte de gerar os eventos de media. Eh chamado externamente
     */
    public function calcula(
        GpevinculomEntity $vinculo, $tipo_movimento, $lista_nr_eventos_origem, TkDateTime $dt_inicial,
        TkDateTime $dt_final, $nrTipoModalidadeCalc, $nrOcorrenciaCalc
    ){
        $this->_listaNrCalculoFolha = $this->_calculo_folha_fonte->retornaCalculoFolhaPeriodo(
            $vinculo->getNrorg(), $tipo_movimento, $dt_inicial, $dt_final, $nrTipoModalidadeCalc, $nrOcorrenciaCalc
        );

        // Gera uma lista chave/valor onde a chave sao os eventos de origem e o valor os de destino
        // $listaCombinada = array_combine(split(',', $lista_nr_eventos_origem), split(',', $lista_nr_eventos_destino));
        // $lista_nr_eventos = $this->_evento->retornaListaEventoMedia($this->_nrOrg);

        if (empty($lista_nr_eventos_origem) === false) {

            /* Normalmente o divisor vem nulo em ferias e com a quantidade de 12 avos no 13 */
            /*  if ($divisor === null) {
                $aux = explode(',', $lista_nr_calculo_folha);
                $divisor = count($aux);
            }*/

            $lista_eventos  = $this->_itens_calculo_fonte->totalizaItensHistorico(
                $vinculo, $this->_listaNrCalculoFolha, $lista_nr_eventos_origem
            );

            return $lista_eventos;


            /*@todo - Criar um metodo para colocar o loop abaixo. O metodo calcula(acima) deve retornar a lista_eventos.
                      A lista combinada deve ser resolvida externamente e ser parametrizada para o metodo calcula.
                      Para a REGRA, vai existir um loop para resolver a lista. Para os demais processos usar o metodo que sera criado.
            */
            /*
            foreach ($lista_eventos as $nr_evento => $evento) {

                $nrEventoDestino = $listaCombinada[$nr_evento];

                $this->_geraEventoMedia(
                    $item_calculo_destino, $nrEventoDestino, $evento[FpaitecalcfolhaEntity::VALOR],
                    $evento[FpaitecalcfolhaEntity::REFERENCIA], $divisor
                );
            }
            */
        } else {
            return;
        }

    }


    /**
     * Enter description here ...
     *
     * @param FpaitecalcfolhaEntity $item_calculo_destino Item Calculo Destino.
     * @param integer               $nr_evento_ant        Numero Evento_ant.
     * @param float                 $total_val            Total_val.
     * @param float                 $total_ref            Total_ref.
     * @param float                 $divisor              Divisor.
     *
     * @return void
     *
     * @author alessandrobartels -
     *         alessandrobartels - 27/06/2011 - Implementacao do NRORG no metodo retornaEvento().
     *         alessandrobartels - 30/11/2012 - O metodo passa a gerar Item de Calculo a partir de uma lista e nao mais de
     *                                          um evento em separado.
     */
    public function geraEventoMedia(
        FpaitecalcfolhaEntity $item_calculo_destino, $listaEventosTotalizados, $listaEventosOrigemDestino, $tipoMovimento,
        $ehMedia, $divisor = null
    ) {

        if ($divisor === null) {
            $aux = explode(',', $this->_listaNrCalculoFolha);
            $divisor = count($aux);
        }

        foreach ($listaEventosTotalizados as $nrEventoOrigem => $eventoTotalizado){

            $nrEventoDestino = $listaEventosOrigemDestino[$nrEventoOrigem];
            $evento = $this->_evento->retornaEvento($nrEventoDestino);

            /* Necessario setar os atributos novamente pois eh criado uma nova instancia de evento.
             * Implementar uma maneira da propria instancia que chama o metodo seja populada.
             */
             $evento->setMesCompetencia($this->_mes_ocorrencia);
            $evento->setDataPagamento($this->_dtPagamento);

            $total_ref = $eventoTotalizado[FpaitecalcfolhaEntity::REFERENCIA]/$divisor;
            $total_val = $eventoTotalizado[FpaitecalcfolhaEntity::VALOR]/$divisor;

            //@todo - criar condicao conforme parametro no evento se gera media para Ferias.
            //if ($tipoMovimento === FpatipomovimentEntity::TP_MOV_FERIAS){

            if ($evento->historico->getIdmediavalref() === FpaeventohEntity::IDMEDIAVALREF_REFERENCIA) {
                /* @todo rever valor 0.001 talvez seja o parm gera valor zro no evento */

				//18-11-2014 Marcelo Conversão da referencia do evento de decimal para hora/minuto no calculo da média
                if ($evento->historico->getIdunidrefereven() === FpaeventohEntity::IDUNIDREFEREVEN_HORA_MINUTO) {
                   $total_ref = FPA::converteDecimalHoraMinuto($total_ref);
                }
                $item_calculo_destino->geraEvento($evento, null, 0.001, $total_ref, 1);
            } else {
                $item_calculo_destino->geraEvento($evento, null, $total_val, 0, 1);
            }

            //} else {
            //    $item_calculo_destino->geraEvento($evento, null, $total_val, $total_ref, 1);
            // }

            /* No caso da media (chamado da Preparacao) é gerado uma base para calculo futuros, por isso o evento eh demonstrativo.
             * No caso da totalizacao (chamado do Calculo) o evento gerado não é uma base, por isso o evento nao eh demonstrativo.
             */
            if ($ehMedia === true){
                $posicao = $item_calculo_destino->procuraEvento($evento, null);
                if ($posicao !== -1) {
                    $item_calculo_destino->atribuiCalculoDemonstrativo(
                        $posicao, FpaitecalcfolhaEntity::IDEVENDEMONCALC_SIM
                    );
                }
            }
        }
    }


}