/*====================PROCEDIMENTO CANCELA_DADOS_FINANCEIRO=====================

   VERIFICA SE AS INFORMAES FINANCEIRAS DA NOTA FISCAL PODEM SER APAGADAS
   DO SISTEMA. EM CASO AFIRMATIVO, A ROTINA APAGA AS INFORMAES FINANCEIRAS
   REFERENTES  NOTA FISCAL APROVADA (AJUSTES E BOLETO). EM CASO CONTRRIO,
   RETORNA UM VALOR CORRESPONDENTE AO MOTIVO DE BLOQUEIO DO CANCELAMENTO.

   -------
   ENTRADA
   -------
      O PROCEDIMENTO POSSUI OS SEGUINTES PARMETROS DE ENTRADA :

      - P_CDFILIAL    : CDIGO DA FILIAL DE LANAMENTO DA NOTA FISCAL
      - P_NRLANCTONF  : NMERO DE LANAMENTO DA NOTA FISCAL

   -----
   SADA
   -----
      O RETORNO DO PROCEDIMENTO SE D ATRAVS DO SEGUINTE PARMETRO :
      - P_RETORNO     : '0' - CANCELAMENTO FINANCEIRO CONCLUDO
                      : '1' - NOTA POSSUI CONTA BAIXADA
                      : '2' - NOTA POSSUI CONTA PARCELADA
                      : '4' - NOTA POSSUI AJUSTES EM BOLETO DAS CONTAS
                      : '5' - NOTA POSSUI CONTA COM BOLETO REAL (PARA CONTAS A PAGAR)
                              NOTA POSSUI CONTA COM BOLETO EMITIDO (PARA CONTAS A RECEBER)
                      : '6' - NOTA POSSUI CONTA ENVIADA AO BANCO VIA CNAB
                      : '7' - NOTA POSSUI CONTA DE UM BOLETO ASSOCIADO
                      : '8' - NOTA DE DEVOLUO POSSUI VALOR UTILIZADO

DEBUGAR PROCEDURE
RAISERROR('', 16,1);

*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'CANCELA_DADOS_FINANCEIRO' AND
                 TYPE = 'P' 		             AND
	              U.UID = O.UID                  AND
	              U.NAME = USER)
DROP PROCEDURE CANCELA_DADOS_FINANCEIRO
GO
CREATE PROCEDURE CANCELA_DADOS_FINANCEIRO(@P_CDFILIAL VARCHAR(4),
                                          @P_NRLANCTONF VARCHAR(10),
                                          @P_IDCANFIN VARCHAR(1) = 'S',
                                          @P_RETORNO FLOAT OUTPUT)
AS
   DECLARE @V_COUNT FLOAT;
   DECLARE @V_FATOR FLOAT;
   DECLARE @V_IDENTRSAID VARCHAR(1);
   DECLARE @V_RESULTADO FLOAT;

   /*VARIVEIS PARA O CURSOR DE CONTAS*/
   DECLARE @V_CDFILIAL VARCHAR(4);
   DECLARE @V_NRLANCTONF VARCHAR(10);
   DECLARE @V_NRSEQ VARCHAR(2);
   DECLARE @V_NRPARC VARCHAR(2);
   DECLARE @V_DTATUAVEN DATETIME;
   DECLARE @V_VRORIG NUMERIC(15,2);
   DECLARE @V_IDMOVFLUXO VARCHAR(1);
   DECLARE @V_DTMOVFLUXO DATETIME;
   DECLARE @V_CDCLASSFINA VARCHAR(6);
   DECLARE @V_CDFILIBOL VARCHAR(4);
   DECLARE @V_NRLANBOL VARCHAR(10);
   DECLARE @V_CDEMPRESA VARCHAR(2);
   DECLARE @V_CDFILMOVFL VARCHAR(4);

   /*VARIVEIS PARA O CURSOR DE AJUSTES*/
   DECLARE @V_AJ_CDFILIAL VARCHAR(4);
   DECLARE @V_AJ_NRLANCTONF VARCHAR(10);
   DECLARE @V_AJ_NRSEQ VARCHAR(2);
   DECLARE @V_AJ_NRPARC VARCHAR(2);
   DECLARE @V_AJ_DTAJUSTE DATETIME;
   DECLARE @V_AJ_CDAJUCT VARCHAR(4);
   DECLARE @V_AJ_IDAJUCT VARCHAR(1);
   DECLARE @V_AJ_CDEMPRESA VARCHAR(2);
   DECLARE @V_AJ_CDFILMOVFL VARCHAR(4);
   DECLARE @V_AJ_CDCLASSFINA VARCHAR(6);
   DECLARE @V_AJ_IDMOVFLUXO VARCHAR(1);
   DECLARE @V_AJ_VRAJUSTE NUMERIC(15,2);
   DECLARE @V_AJ_DTMOVFLUXO DATETIME;

   /*VARIVEIS PARA O CURSO C_ITEMNOTA*/
   DECLARE @V_ITEMNOTA_CDFILIALIT VARCHAR(4);
   DECLARE @V_ITEMNOTA_NRLANCTONFIT VARCHAR(10);
BEGIN
   /*BUSCA AS INFORMAES DA NOTA FISCAL*/
   SELECT @V_IDENTRSAID = IDENTRSAIDOP
     FROM NOTAFISCAL
    WHERE CDFILIAL = @P_CDFILIAL
      AND NRLANCTONF = @P_NRLANCTONF;
   /*NOTA FISCAL DE ENTRADA*/
   IF @V_IDENTRSAID = 'E' BEGIN
      /*VERIFICA EXISTNCIA DE CONTA A PAGAR BAIXADA*/
      SELECT @V_COUNT = COUNT(BO.CDFILIAL)
        FROM CONTAPAGAR CP,
             BOLETPAGAR BO
       WHERE (CP.CDFILIAL    = @P_CDFILIAL)
         AND (CP.NRLANCTONF  = @P_NRLANCTONF)
         AND (BO.CDFILIAL    = CP.CDFILIBPAG)
         AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
         AND (BO.NRBAIXAPAG IS NOT NULL);
      IF @V_COUNT > 0 BEGIN
         SET @P_RETORNO = 1;
      END
      ELSE BEGIN
         /*VERIFICA EXISTNCIA DE CONTAS PARCELADAS*/
         SELECT @V_COUNT = COUNT(*)
           FROM CONTAPAGAR CP
          WHERE (CP.CDFILIAL = @P_CDFILIAL)
            AND (CP.NRLANCTONF = @P_NRLANCTONF)
            AND (SELECT COUNT(*)
                   FROM CONTAPAGAR
                  WHERE CDFILIAL = CP.CDFILIAL
                    AND NRLANCTONF = CP.NRLANCTONF
                    AND NRSEQVENPAG = CP.NRSEQVENPAG) > 1;
         IF @V_COUNT > 0 BEGIN
            SET @P_RETORNO = 2;
         END
         ELSE BEGIN
            /*VERIFICA EXISTNCIA DE BOLETO REAL*/
            SELECT @V_COUNT = COUNT(BO.CDFILIAL)
              FROM CONTAPAGAR CP,
                   BOLETPAGAR BO
             WHERE (CP.CDFILIAL = @P_CDFILIAL)
               AND (CP.NRLANCTONF = @P_NRLANCTONF)
               AND (BO.CDFILIAL = CP.CDFILIBPAG)
               AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
               AND (BO.IDBPAGREAL = 'S');
            IF @V_COUNT > 0 BEGIN
               SET @P_RETORNO = 5;
            END
            ELSE BEGIN
               /*VERIFICA EXISTNCIA DE BOLETO LIGADO  REMESSA*/
               SELECT @V_COUNT = COUNT(BO.CDFILIAL)
                 FROM CONTAPAGAR CP,
                      BOLETPAGAR BO
                WHERE (CP.CDFILIAL = @P_CDFILIAL)
                  AND (CP.NRLANCTONF = @P_NRLANCTONF)
                  AND (BO.CDFILIAL = CP.CDFILIBPAG)
                  AND (BO.NRLANBOLPAG = CP.NRLANBOLPAG)
                  AND (IDSITUCNABP <> '00');
               IF @V_COUNT > 0 BEGIN
                  SET @P_RETORNO = 6;
               END
               ELSE BEGIN
                  /*VERIFICA EXISTNCIA DE BOLETO ASSOCIADO  NOTA FISCAL DIFERENTE*/
                  SELECT @V_COUNT = COUNT(*)
                    FROM (SELECT DISTINCT C.CDFILIAL, C.NRLANCTONF
                            FROM CONTAPAGAR C,
                                (SELECT DISTINCT CDFILIBPAG as CDFILIAL, NRLANBOLPAG
                                   FROM CONTAPAGAR CP
                                  WHERE (CP.CDFILIAL   = @P_CDFILIAL)
                                    AND (CP.NRLANCTONF = @P_NRLANCTONF)) BO
                   WHERE BO.CDFILIAL    = C.CDFILIBPAG
                     AND BO.NRLANBOLPAG = C.NRLANBOLPAG) A;
                  IF @V_COUNT > 1 BEGIN
                     SET @P_RETORNO = 7;
                  END
                  ELSE BEGIN
                     /*VERIFICA SE A NOTA FISCAL DE DEVOLUO TEM VALOR UTILIZADO*/
                     SELECT @V_COUNT = ISNULL(VRDEVOLNFUTL,0)
                       FROM NOTAFISCAL
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF;
                     IF @V_COUNT > 0 BEGIN
                        SET @P_RETORNO = 8;
                     END
                     ELSE BEGIN
                        /*VERIFICA SE A NOTA POSSUI VENCIMENTOS LIGADOS  ANTECIPAO DE FORNECEDORES
                        (MENSAGEM DE DOCUMENTO POSSUI BOLETO REAL)*/
                        SELECT @V_COUNT = COUNT(B.CDFILIAL)
                          FROM CONTAPAGAR C, BOLETPAGAR B
                         WHERE C.CDFILIAL = @P_CDFILIAL
                           AND C.NRLANCTONF = @P_NRLANCTONF
                           AND C.CDFILIBPAG = B.CDFILIAL
                           AND C.NRLANBOLPAG = B.NRLANBOLPAG
                           AND B.NRLANCANTECIPA IS NOT NULL;
                        IF @V_COUNT > 0 BEGIN
                           SET @P_RETORNO = 5;
                        END
                        ELSE BEGIN
                           /*PESQUISA A EXISTNCIA DE AJUSTES NOS BOLETOS DAS CONTAS*/
                           SELECT @V_COUNT = COUNT(AJ.CDFILIAL)
                             FROM CONTAPAGAR CP,
                                  AJBOLPAG   AJ
                            WHERE (CP.CDFILIAL = @P_CDFILIAL)
                              AND (CP.NRLANCTONF = @P_NRLANCTONF)
                              AND (AJ.CDFILIAL = CP.CDFILIBPAG)
                              AND (AJ.NRLANBOLPAG = CP.NRLANBOLPAG);
                           IF @V_COUNT > 0 BEGIN
                              SET @P_RETORNO = 4;
                           END
                           ELSE BEGIN
                              SET @P_RETORNO = 0;
                              IF (ISNULL(@P_IDCANFIN, 'S') = 'S') BEGIN
                                 /*APAGA AS CONTAS A PAGAR*/
                                 DECLARE C_CNTPAGAR CURSOR FOR
                                    SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                           DTATUAVENPAG, VRORIGPAG, IDMOVFLUXO, DTMOVFLUXO,
                                           CDCLASSFINA, CDFILIBPAG, NRLANBOLPAG, CDEMPRESA, CDFIMOVFLPAG
                                      FROM CONTAPAGAR
                                     WHERE CDFILIAL = @P_CDFILIAL
                                       AND NRLANCTONF = @P_NRLANCTONF;
                                 OPEN C_CNTPAGAR;
                                 FETCH NEXT FROM C_CNTPAGAR INTO
                                 @V_CDFILIAL,
                                 @V_NRLANCTONF,
                                 @V_NRSEQ,
                                 @V_NRPARC,
                                 @V_DTATUAVEN,
                                 @V_VRORIG,
                                 @V_IDMOVFLUXO,
                                 @V_DTMOVFLUXO,
                                 @V_CDCLASSFINA,
                                 @V_CDFILIBOL,
                                 @V_NRLANBOL,
                                 @V_CDEMPRESA,
                                 @V_CDFILMOVFL;
                                 WHILE (@@FETCH_STATUS = 0) BEGIN
                                    /*ATUALIZA ORAMENTO FINANCEIRO FINANCEIRO*/
                                    SET @V_RESULTADO = (@V_VRORIG * -1);
                                    EXEC ORCAMENTO_OK @V_CDEMPRESA,
                                             @V_CDFILMOVFL,
                                             @V_CDCLASSFINA,
                                             @V_DTATUAVEN,
                                             @V_RESULTADO,
                                             @V_RESULTADO OUTPUT;
                                    /*APAGA O RATEIO DA CONTA A PAGAR*/
                                    DELETE FROM RATCTPAGAR
                                     WHERE CDFILIAL     = @V_CDFILIAL
                                       AND NRLANCTONF   = @V_NRLANCTONF
                                       AND NRSEQVENPAG  = @V_NRSEQ
                                       AND NRPARCELAPAG = @V_NRPARC;
                                    /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                    DECLARE C_AJPAGAR CURSOR FOR
                                    SELECT AJ.CDFILIAL, AJ.NRLANCTONF, AJ.NRSEQVENPAG, AJ.NRPARCELAPAG,
                                           AJ.DTAJUSTEPAG, AJ.CDAJUCTPAG, T.IDAJUCTPAG, AJ.CDEMMFAJCNTP,
                                           AJ.CDFIMFAJCNTP, AJ.CDCLASSFINA, AJ.IDMOVFLUXO, AJ.VRAJUSTEPAG,
                                           AJ.DTMOVFLUXO
                                      FROM AJCTPAGAR AJ, TIPOAJPAGAR T
                                     WHERE AJ.CDFILIAL = @V_CDFILIAL
                                       AND AJ.NRLANCTONF = @V_NRLANCTONF
                                       AND AJ.NRSEQVENPAG = @V_NRSEQ
                                       AND AJ.NRPARCELAPAG = @V_NRPARC
                                       AND AJ.CDAJUCTPAG = T.CDAJUCTPAG;
                                    OPEN C_AJPAGAR;
                                    FETCH NEXT FROM C_AJPAGAR INTO
                                    @V_AJ_CDFILIAL ,
                                    @V_AJ_NRLANCTONF,
                                    @V_AJ_NRSEQ,
                                    @V_AJ_NRPARC,
                                    @V_AJ_DTAJUSTE,
                                    @V_AJ_CDAJUCT,
                                    @V_AJ_IDAJUCT,
                                    @V_AJ_CDEMPRESA,
                                    @V_AJ_CDFILMOVFL,
                                    @V_AJ_CDCLASSFINA,
                                    @V_AJ_IDMOVFLUXO,
                                    @V_AJ_VRAJUSTE,
                                    @V_AJ_DTMOVFLUXO;
                                    WHILE (@@FETCH_STATUS = 0) BEGIN
                                       IF @V_AJ_IDAJUCT = 'D' BEGIN
                                          SET @V_FATOR = 1;
                                       END
                                       ELSE BEGIN
                                          SET @V_FATOR = -1;
                                       END;
                                       IF NOT (@V_AJ_CDEMPRESA IS NULL)
                                          AND NOT (@V_AJ_CDFILMOVFL IS NULL)
                                          AND NOT (@V_AJ_DTMOVFLUXO IS NULL)
                                          AND NOT (@V_AJ_CDCLASSFINA IS NULL) BEGIN
                                          /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                          SET @V_RESULTADO = (@V_AJ_VRAJUSTE * @V_FATOR);
                                          EXEC ATUALIZA_FLUXO_DE_CAIXA @V_AJ_CDEMPRESA,
                                                                       @V_AJ_CDFILMOVFL,
                                                                       @V_AJ_DTMOVFLUXO,
                                                                       @V_AJ_IDMOVFLUXO,
                                                                       @V_AJ_CDCLASSFINA,
                                                                       0,
                                                                       @V_RESULTADO;
                                       END;
                                       /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                       DELETE FROM AJCTPAGAR
                                        WHERE (CDFILIAL     = @V_AJ_CDFILIAL)
                                          AND (NRLANCTONF   = @V_AJ_NRLANCTONF)
                                          AND (NRSEQVENPAG  = @V_AJ_NRSEQ)
                                          AND (NRPARCELAPAG = @V_AJ_NRPARC)
                                          AND (DTAJUSTEPAG  = @V_AJ_DTAJUSTE)
                                          AND (CDAJUCTPAG   = @V_AJ_CDAJUCT);

                                       FETCH NEXT FROM C_AJPAGAR INTO
                                       @V_AJ_CDFILIAL ,
                                       @V_AJ_NRLANCTONF,
                                       @V_AJ_NRSEQ,
                                       @V_AJ_NRPARC,
                                       @V_AJ_DTAJUSTE,
                                       @V_AJ_CDAJUCT,
                                       @V_AJ_IDAJUCT,
                                       @V_AJ_CDEMPRESA,
                                       @V_AJ_CDFILMOVFL,
                                       @V_AJ_CDCLASSFINA,
                                       @V_AJ_IDMOVFLUXO,
                                       @V_AJ_VRAJUSTE,
                                       @V_AJ_DTMOVFLUXO;
                                    END;
                                    CLOSE C_AJPAGAR;
                                    DEALLOCATE C_AJPAGAR;
                                    /*ATUALIZA O FLUXO DE CAIXA DA CONTA A PAGAR*/
                                    /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                    IF NOT (@V_CDEMPRESA IS NULL)
                                       AND NOT (@V_CDFILMOVFL IS NULL)
                                       AND NOT (@V_DTMOVFLUXO IS NULL)
                                       AND NOT (@V_CDCLASSFINA IS NULL) BEGIN
                                       SET @V_RESULTADO = (@V_VRORIG * -1);
                                       EXEC ATUALIZA_FLUXO_DE_CAIXA @V_CDEMPRESA,
                                                                    @V_CDFILMOVFL,
                                                                    @V_DTMOVFLUXO,
                                                                    @V_IDMOVFLUXO,
                                                                    @V_CDCLASSFINA,
                                                                    0,
                                                                    @V_RESULTADO;
                                    END;

                                    /*ATUALIZA AS INFORMAES DA CONTA A PAGAR, RETIRANDO
                                    AS INFORMAES ATUALIZADAS NA APROVAO*/
                                    UPDATE CONTAPAGAR
                                       SET
                                          CDTPCTPAGAR = NULL,
                                          CDFILIBPAG = NULL,
                                          NRLANBOLPAG = NULL,
                                          CDCLASSFINA = NULL,
                                          CDEMPRESA = NULL,
                                          CDFIMOVFLPAG = NULL,
                                          DTMOVFLUXO = NULL,
                                          IDMOVFLUXO = NULL,
                                          DSCONTAPAG = NULL,
                                          VRATUAPAG = VRORIGPAG
                                       WHERE CDFILIAL = @V_CDFILIAL
                                         AND NRLANCTONF = @V_NRLANCTONF
                                         AND NRSEQVENPAG = @V_NRSEQ
                                         AND NRPARCELAPAG = @V_NRPARC;

                                    SELECT @V_COUNT = COUNT(*)
                                      FROM CONTAPAGAR
                                     WHERE CDFILIBPAG  = @V_CDFILIBOL
                                       AND NRLANBOLPAG = @V_NRLANBOL;

                                    /*APAGA O BOLETO RELACIONADO  CONTA A PAGAR*/
                                    IF @V_COUNT = 0 BEGIN
                                       DELETE FROM BOLETPAGAR
                                        WHERE CDFILIAL = @V_CDFILIBOL
                                          AND NRLANBOLPAG = @V_NRLANBOL;
                                    END;

                                    FETCH NEXT FROM C_CNTPAGAR INTO
                                    @V_CDFILIAL,
                                    @V_NRLANCTONF,
                                    @V_NRSEQ,
                                    @V_NRPARC,
                                    @V_DTATUAVEN,
                                    @V_VRORIG,
                                    @V_IDMOVFLUXO,
                                    @V_DTMOVFLUXO,
                                    @V_CDCLASSFINA,
                                    @V_CDFILIBOL,
                                    @V_NRLANBOL,
                                    @V_CDEMPRESA,
                                    @V_CDFILMOVFL;
                                 END;
                                 CLOSE C_CNTPAGAR;
                                 DEALLOCATE C_CNTPAGAR;

                                 DECLARE C_ITEMNOTA CURSOR FOR SELECT CDFILIALIT, NRLANCTONFIT
                                                                 FROM ITEMNOTAFISC
                                                                WHERE CDFILIAL   = @P_CDFILIAL
                                                                  AND NRLANCTONF = @P_NRLANCTONF;
                                 OPEN C_ITEMNOTA;
                                 FETCH NEXT FROM C_ITEMNOTA INTO @V_ITEMNOTA_CDFILIALIT, @V_ITEMNOTA_NRLANCTONFIT;

                                  /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                                 WHILE (@@FETCH_STATUS = 0) BEGIN
                                    EXEC AJUSTE_CONTAPAGAR_NF @V_ITEMNOTA_CDFILIALIT,
                                                              @V_ITEMNOTA_NRLANCTONFIT,
                                                              'P';

                                    FETCH NEXT FROM C_ITEMNOTA INTO @V_ITEMNOTA_CDFILIALIT, @V_ITEMNOTA_NRLANCTONFIT;
                                 END;
                                 CLOSE C_ITEMNOTA;
                                 DEALLOCATE C_ITEMNOTA;

                                 /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                                 EXEC AJUSTE_CONTAPAGAR_NF @P_CDFILIAL,
                                                           @P_NRLANCTONF,
                                                           'P';
                              END;
                           END;
                        END;
                     END;
                  END;
               END;
            END;
         END;
      END;
   END
   /*NOTA FISCAL DE SADA*/
   ELSE BEGIN
      IF @V_IDENTRSAID = 'S' BEGIN
         /*VERIFICA EXISTNCIA DE CONTA A RECEBER BAIXADA*/
         SELECT @V_COUNT = COUNT(BO.CDFILIAL)
           FROM CONTARECEBER CR,
                BOLETRECEBER BO
          WHERE (CR.CDFILIAL    = @P_CDFILIAL)
            AND (CR.NRLANCTONF  = @P_NRLANCTONF)
            AND (BO.CDFILIAL    = CR.CDFILIBOLREC)
            AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
            AND (BO.NRBAIXAREC IS NOT NULL);
         IF @V_COUNT > 0 BEGIN
            SET @P_RETORNO = 1;
         END
         ELSE BEGIN
            /*VERIFICA EXISTNCIA DE CONTAS PARCELADAS*/
            SELECT @V_COUNT = COUNT(*)
              FROM CONTARECEBER CR
             WHERE (CR.CDFILIAL = @P_CDFILIAL)
               AND (CR.NRLANCTONF = @P_NRLANCTONF)
               AND (SELECT COUNT(*)
                      FROM CONTARECEBER
                     WHERE CDFILIAL = CR.CDFILIAL
                       AND NRLANCTONF = CR.NRLANCTONF
                       AND NRSEQVENREC = CR.NRSEQVENREC) > 1;
            IF @V_COUNT > 0 BEGIN
               SET @P_RETORNO = 2;
            END
            ELSE BEGIN
               /*VERIFICA EXISTNCIA DE BOLETO EMITIDO*/
               SELECT @V_COUNT = COUNT(BO.CDFILIAL)
                 FROM CONTARECEBER CR,
                      BOLETRECEBER BO
                WHERE (CR.CDFILIAL = @P_CDFILIAL)
                  AND (CR.NRLANCTONF = @P_NRLANCTONF)
                  AND (BO.CDFILIAL = CR.CDFILIBOLREC)
                  AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
                  AND (BO.IDSTATBREC = 'E');
               IF @V_COUNT > 0 BEGIN
                  SET @P_RETORNO = 5;
               END
               ELSE BEGIN
                  /*VERIFICA EXISTNCIA DE BOLETO LIGADO  REMESSA*/
                  SELECT @V_COUNT = COUNT(BO.CDFILIAL)
                    FROM CONTARECEBER CR,
                         BOLETRECEBER BO
                   WHERE (CR.CDFILIAL = @P_CDFILIAL)
                     AND (CR.NRLANCTONF = @P_NRLANCTONF)
                     AND (BO.CDFILIAL = CR.CDFILIBOLREC)
                     AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
                     AND (IDSITUCNABR <> '00');
                  IF @V_COUNT > 0 BEGIN
                     SET @P_RETORNO = 6;
                  END
                  ELSE BEGIN
                     /*VERIFICA EXISTNCIA DE BOLETO ASSOCIADO  NOTA FISCAL DIFERENTE*/
                     SELECT @V_COUNT = COUNT(BO.CDFILIAL)
                       FROM CONTARECEBER CR,
                            BOLETRECEBER BO
                      WHERE (CR.CDFILIAL = @P_CDFILIAL)
                        AND (CR.NRLANCTONF = @P_NRLANCTONF)
                        AND (BO.CDFILIAL = CR.CDFILIBOLREC)
                        AND (BO.NRLANBOLREC = CR.NRLANBOLREC)
                        AND (SELECT COUNT(*)
                               FROM CONTARECEBER
                              WHERE CDFILIBOLREC = BO.CDFILIAL
                                AND NRLANBOLREC = BO.NRLANBOLREC) > 1;
                     IF @V_COUNT > 0 BEGIN
                        SET @P_RETORNO = 7;
                     END
                     ELSE BEGIN
                        /*VERIFICA SE A NOTA FISCAL DE DEVOLUO TEM VALOR UTILIZADO*/
                        SELECT @V_COUNT = ISNULL(VRDEVOLNFUTL,0)
                          FROM NOTAFISCAL
                         WHERE CDFILIAL = @P_CDFILIAL
                           AND NRLANCTONF = @P_NRLANCTONF;
                        IF @V_COUNT > 0 BEGIN
                           SET @P_RETORNO = 8;
                        END
                        ELSE BEGIN
                           /*PESQUISA A EXISTNCIA DE AJUSTES NOS BOLETOS DAS CONTAS*/
                           SELECT @V_COUNT = COUNT(AJ.CDFILIAL)
                             FROM CONTARECEBER CR,
                                  AJBOLREC   AJ
                            WHERE (CR.CDFILIAL = @P_CDFILIAL)
                              AND (CR.NRLANCTONF = @P_NRLANCTONF)
                              AND (AJ.CDFILIAL = CR.CDFILIBOLREC)
                              AND (AJ.NRLANBOLREC = CR.NRLANBOLREC);
                           IF @V_COUNT > 0 BEGIN
                              SET @P_RETORNO = 4;
                           END
                           ELSE BEGIN
                              SET @P_RETORNO = 0;

                              IF (ISNULL(@P_IDCANFIN, 'S') = 'S') BEGIN
                                 /*APAGA AS CONTAS A RECEBER*/
                                 DECLARE C_CNTRECEBER CURSOR FOR
                                 SELECT CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC,
                                        DTATUAVENREC, VRORIGREC, IDMOVFLUXO, DTMOVFLUXO,
                                        CDCLASSFINA, CDFILIBOLREC, NRLANBOLREC, CDEMPRESA, CDFIMOVFLREC
                                   FROM CONTARECEBER
                                  WHERE CDFILIAL = @P_CDFILIAL
                                    AND NRLANCTONF = @P_NRLANCTONF;
                                 OPEN C_CNTRECEBER;
                                 FETCH NEXT FROM C_CNTRECEBER INTO
                                 @V_CDFILIAL,
                                 @V_NRLANCTONF,
                                 @V_NRSEQ,
                                 @V_NRPARC,
                                 @V_DTATUAVEN,
                                 @V_VRORIG,
                                 @V_IDMOVFLUXO,
                                 @V_DTMOVFLUXO,
                                 @V_CDCLASSFINA,
                                 @V_CDFILIBOL,
                                 @V_NRLANBOL,
                                 @V_CDEMPRESA,
                                 @V_CDFILMOVFL;
                                 WHILE (@@FETCH_STATUS = 0) BEGIN
                                    /*ATUALIZA ORAMENTO FINANCEIRO FINANCEIRO*/
                                    SET @V_RESULTADO = (@V_VRORIG * -1);
                                    EXEC ORCAMENTO_OK @V_CDEMPRESA,
                                                      @V_CDFILMOVFL,
                                                      @V_CDCLASSFINA,
                                                      @V_DTATUAVEN,
                                                      @V_RESULTADO,
                                                      @V_RESULTADO OUTPUT;
                                    /*APAGA O RATEIO DA CONTA A PAGAR*/
                                    DELETE FROM RATCTRECEBER
                                     WHERE CDFILIAL     = @V_CDFILIAL
                                       AND NRLANCTONF   = @V_NRLANCTONF
                                       AND NRSEQVENREC  = @V_NRSEQ
                                       AND NRPARCELAREC = @V_NRPARC;
                                    /*APAGA OS AJUSTES DA CONTA A PAGAR*/
                                    DECLARE C_AJRECEBER CURSOR FOR
                                    SELECT AJ.CDFILIAL, AJ.NRLANCTONF, AJ.NRSEQVENREC, AJ.NRPARCELAREC,
                                           AJ.DTAJUSTEREC, AJ.CDAJUCTREC, T.IDAJUCTREC, AJ.CDEMMFAJCNTR,
                                           AJ.CDFIMFAJCNTR, AJ.CDCLASSFINA, AJ.IDMOVFLUXO, AJ.VRAJUSTEREC,
                                           AJ.DTMOVFLUXO
                                      FROM AJCTRECEBER AJ, TIPOAJRECEBER T
                                     WHERE AJ.CDFILIAL = @V_CDFILIAL
                                       AND AJ.NRLANCTONF = @V_NRLANCTONF
                                       AND AJ.NRSEQVENREC = @V_NRSEQ
                                       AND AJ.NRPARCELAREC = @V_NRPARC
                                       AND AJ.CDAJUCTREC = T.CDAJUCTREC;
                                    OPEN C_AJRECEBER;
                                    FETCH NEXT FROM C_AJRECEBER INTO
                                    @V_AJ_CDFILIAL ,
                                    @V_AJ_NRLANCTONF,
                                    @V_AJ_NRSEQ,
                                    @V_AJ_NRPARC,
                                    @V_AJ_DTAJUSTE,
                                    @V_AJ_CDAJUCT,
                                    @V_AJ_IDAJUCT,
                                    @V_AJ_CDEMPRESA,
                                    @V_AJ_CDFILMOVFL,
                                    @V_AJ_CDCLASSFINA,
                                    @V_AJ_IDMOVFLUXO,
                                    @V_AJ_VRAJUSTE,
                                    @V_AJ_DTMOVFLUXO;
                                    WHILE (@@FETCH_STATUS = 0) BEGIN
                                       IF @V_AJ_IDAJUCT = 'D' BEGIN
                                          SET @V_FATOR = 1;
                                       END
                                       ELSE BEGIN
                                          SET @V_FATOR = -1;
                                       END;
                                       IF NOT (@V_AJ_CDEMPRESA IS NULL)
                                          AND NOT (@V_AJ_CDFILMOVFL IS NULL)
                                          AND NOT (@V_AJ_DTMOVFLUXO IS NULL)
                                          AND NOT (@V_AJ_CDCLASSFINA IS NULL) BEGIN
                                          /*ATUALIZAO DO FLUXO DE CAIXA DO AJUSTE*/
                                          SET @V_RESULTADO = (@V_AJ_VRAJUSTE * @V_FATOR);
                                          EXEC ATUALIZA_FLUXO_DE_CAIXA @V_AJ_CDEMPRESA,
                                                                       @V_AJ_CDFILMOVFL,
                                                                       @V_AJ_DTMOVFLUXO,
                                                                       @V_AJ_IDMOVFLUXO,
                                                                       @V_AJ_CDCLASSFINA,
                                                                       @V_RESULTADO,
                                                                       0;
                                       END;
                                       /*APAGA OS AJUSTES DA CONTA A RECEBER*/
                                       DELETE FROM AJCTRECEBER
                                        WHERE (CDFILIAL     = @V_AJ_CDFILIAL)
                                          AND (NRLANCTONF   = @V_AJ_NRLANCTONF)
                                          AND (NRSEQVENREC  = @V_AJ_NRSEQ)
                                          AND (NRPARCELAREC = @V_AJ_NRPARC)
                                          AND (DTAJUSTEREC  = @V_AJ_DTAJUSTE)
                                          AND (CDAJUCTREC   = @V_AJ_CDAJUCT);

                                       FETCH NEXT FROM C_AJRECEBER INTO
                                       @V_AJ_CDFILIAL ,
                                       @V_AJ_NRLANCTONF,
                                       @V_AJ_NRSEQ,
                                       @V_AJ_NRPARC,
                                       @V_AJ_DTAJUSTE,
                                       @V_AJ_CDAJUCT,
                                       @V_AJ_IDAJUCT,
                                       @V_AJ_CDEMPRESA,
                                       @V_AJ_CDFILMOVFL,
                                       @V_AJ_CDCLASSFINA,
                                       @V_AJ_IDMOVFLUXO,
                                       @V_AJ_VRAJUSTE,
                                       @V_AJ_DTMOVFLUXO;
                                    END;
                                    CLOSE C_AJRECEBER;
                                    DEALLOCATE C_AJRECEBER;
                                    /*ATUALIZA O FLUXO DE CAIXA DA CONTA A RECEBER*/
                                    IF NOT (@V_CDEMPRESA IS NULL)
                                       AND NOT (@V_CDFILMOVFL IS NULL)
                                       AND NOT (@V_DTMOVFLUXO IS NULL)
                                       AND NOT (@V_CDCLASSFINA IS NULL) BEGIN
                                       SET @V_RESULTADO = (@V_VRORIG * -1);
                                       EXEC ATUALIZA_FLUXO_DE_CAIXA @V_CDEMPRESA,
                                                                    @V_CDFILMOVFL,
                                                                    @V_DTMOVFLUXO,
                                                                    @V_IDMOVFLUXO,
                                                                    @V_CDCLASSFINA,
                                                                    @V_RESULTADO,
                                                                    0;
                                    END;
                                    /*ATUALIZA AS INFORMAES DA CONTA A RECEBER, RETIRANDO
                                    AS INFORMAES ATUALIZADAS NA APROVAO*/
                                    UPDATE CONTARECEBER
                                       SET
                                          CDTPCTRECEB = NULL,
                                          CDFILIBOLREC = NULL,
                                          NRLANBOLREC = NULL,
                                          CDCLASSFINA = NULL,
                                          CDEMPRESA = NULL,
                                          CDFIMOVFLREC = NULL,
                                          DTMOVFLUXO = NULL,
                                          IDMOVFLUXO = NULL,
                                          DSCONTAREC = NULL,
                                          VRATUAREC = VRORIGREC
                                       WHERE CDFILIAL = @V_CDFILIAL
                                         AND NRLANCTONF = @V_NRLANCTONF
                                         AND NRSEQVENREC = @V_NRSEQ
                                         AND NRPARCELAREC = @V_NRPARC;
                                    /*APAGA O BOLETO RELACIONADO  CONTA A RECEBER*/
                                    DELETE FROM BOLETRECEBER
                                     WHERE CDFILIAL = @V_CDFILIBOL
                                       AND NRLANBOLREC = @V_NRLANBOL;
                                    FETCH NEXT FROM C_CNTRECEBER INTO
                                    @V_CDFILIAL,
                                    @V_NRLANCTONF,
                                    @V_NRSEQ,
                                    @V_NRPARC,
                                    @V_DTATUAVEN,
                                    @V_VRORIG,
                                    @V_IDMOVFLUXO,
                                    @V_DTMOVFLUXO,
                                    @V_CDCLASSFINA,
                                    @V_CDFILIBOL,
                                    @V_NRLANBOL,
                                    @V_CDEMPRESA,
                                    @V_CDFILMOVFL;
                                 END;
                                 CLOSE C_CNTRECEBER;
                                 DEALLOCATE C_CNTRECEBER;
                              END;
                           END;
                        END;
                     END;
                  END;
               END;
            END;
         END;
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CANCELA_DADOS_FINANCEIRO','5.42.xxx';
GO
