/*
 @C:\Win_Prj\Sql\SqlServer\5008_DF_STP_Consulta_GrupoFiscal.sql

 Descrio:
 Procedure para consulta do grupo fiscal que ser utilizado na parametrizao fiscal

 Criao:
 29/08/2001 - Roberto A. Lopes Martins

 Parmetros:

 P_IDORIGDESTNF - Identificador de origem e destino do lanamento
                  "F" - Fornecedor
                  "C" - Cliente
                  "L" = Filial
 P_CDORIGDESTNF - Cdigo da pessoa de origem ou destino do lanamento. Depende do primeiro parmetro.
 P_CDFILIFATUR  - Cdigo da filial emitente da nota fiscal em caso de documento de faturamento.
                  Se no for nota fiscal gerada atravs de apurao de faturamento = ''.
 P_IDENTRSAIDOP - Sentido da Operao
                  "E" - Entrada
                  "S" - Sada
 P_CDTIPOOPER   - Tipo de Operao do lanamento
 P_CDGRUPOFISC  - Parmetro que retorna o grupo fiscal utilizado.


 Exemplo da utilizao.

 Esta procedure deve ser chamada apenas uma vez dentro da procedure, no  necessrio executar a
 cada vez que for chamar as procedures de consulta de parametrizao fiscal.

 "
 ...
 EXEC CONSULTA_GRUPOFISCAL(V_IDORIGDESTNF, V_CDFORNECED, '', 'E', V_CDTIPOOPER, V_CDGRUPOFISC);
 ...

 EXEC CONSULTA_ALIQUOTA(V_CDIMPOSTO, 'E', V_CDEMPRESA, V_CDPRODUTO, V_CDINSCESTA,
                        V_CDPAISORIG, V_SGESTAORIG, V_CDPAISDEST, V_SGESTADEST, V_CDMUNIORIG,
                        V_VRBASECALC, V_DTINIVALID, V_CDFILIAL, V_NRLANCTONF, V_CDGRUPOFISC);
 ...
 "

 Manutenes:
 04/10/2001 - Ana Paula da Silva - Converso para SqlServer
*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'CONSULTA_GRUPOFISCAL' AND
	        TYPE = 'P' 			             AND
	        U.UID = O.UID             	    AND
	        U.NAME = USER)
DROP PROCEDURE CONSULTA_GRUPOFISCAL
GO
CREATE PROCEDURE CONSULTA_GRUPOFISCAL
                 @P_IDORIGDESTNF  VARCHAR(01),
                 @P_CDORIGDESTNF  VARCHAR(21),
                 @P_CDFILIFATUR   VARCHAR(04),
                 @P_IDENTRSAIDOP  VARCHAR(01),
                 @P_CDTIPOOPER    VARCHAR(02),
                 @P_CDGRUPOFISC   VARCHAR(03) OUTPUT
AS
   DECLARE @V_CDGRUPOFISC VARCHAR(03);
BEGIN
   SET @V_CDGRUPOFISC = NULL;

   IF @P_IDORIGDESTNF = 'F' BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM FORNECEDOR
      WHERE CDFORNECED = @P_CDORIGDESTNF;
   END
   ELSE IF @P_IDORIGDESTNF = 'C' BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM CLIENTE
      WHERE CDCLIENTE = @P_CDORIGDESTNF;
   END
   ELSE BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM FILIAL
      WHERE CDFILIAL = @P_CDORIGDESTNF;
   END;

   IF @V_CDGRUPOFISC IS NULL BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM PARAMFILIAL
      WHERE CDFILIAL = @P_CDFILIFATUR;
   END;

   IF @V_CDGRUPOFISC IS NULL BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM TIPOOPERAC
      WHERE IDENTRSAIDOP = @P_IDENTRSAIDOP AND
            CDTIPOOPER   = @P_CDTIPOOPER;
   END;

   IF @V_CDGRUPOFISC IS NULL BEGIN
      SELECT @V_CDGRUPOFISC = MAX(CDGRUPOFISC)
      FROM TPFATURFIS T, FILTPFATURFIS F
      WHERE T.CDTPFATURFIS = F.CDTPFATURFIS
        AND F.CDFILIAL     = @P_CDFILIFATUR;
   END;
   SET @P_CDGRUPOFISC = @V_CDGRUPOFISC;
END
;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CONSULTA_GRUPOFISCAL','5.01.014';
GO

